@@ -45,7 +45,7 @@ class ClusterConnection(Connection):
     "Manages TCP communication to and from a Redis server"
 
     def __init__(self, *args, **kwargs):
-        log.info("Createing new ClusterConnection instance")
+        log.debug("Createing new ClusterConnection instance")
         log.debug(str(args) + " : " + str(kwargs))
 
         self.readonly = kwargs.pop('readonly', False)
@@ -123,7 +123,7 @@ class ClusterConnectionPool(ConnectionPool):
             it was operating on. This will allow the client to drift along side the cluster
             if the cluster nodes move around a lot.
         """
-        log.info("Creating new ClusterConnectionPool instance")
+        log.debug("Creating new ClusterConnectionPool instance")
 
         if connection_class is None:
             connection_class = ClusterConnection
@@ -262,7 +262,7 @@ class ClusterConnectionPool(ConnectionPool):
         We need to drop this connection and recreate a new one
         """
         try:
-            connection.close()
+            connection.disconnect()
         except Exception:
             log.exception("drop connection is failed for {}".format(node))
         finally:
